==> piwigo-2.1.6.zip: piwigo/language/da_DK/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'Opgrader';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Denne side foreslår at opgradere databasen fra din gamle version af Piwigo til den nye version. Opgraderingsassistenten tror du burger en<strong>release %s</strong> (or equivalent).';
$lang['Upgrade from version %s to %s'] = 'Opgrader fra version %s til %s';
$lang['Statistics'] = 'Statistik';
$lang['total upgrade time'] = 'total opgraderings tid';
$lang['total SQL time'] = 'total SQL tid';
$lang['SQL queries'] = 'SQL queries';
$lang['Upgrade informations'] = 'Opgraderings information';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Udfør et vedligeholdelsescheck I [Administration>Tools>Maintenance] hvis du oplever problemer.';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'For en sikkerheds skyld er følgende plugins blevet deaktiveret. Check dine plugins opgraderinger før du reaktiverer dem:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Kun en administrator kan lave en opgradering: Login in herunder.';
$lang['You do not have access rights to run upgrade'] = 'Du har ikke adgangsrettighed til at køre en opgradering';
$lang['All sub-categories of private categories become private'] = 'Alle under-kategorier af private kategorier bliver private';
$lang['User permissions and group permissions have been erased'] = 'Bruger og gruppe tilladelser er blevet slettet';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Kun  thumbnails prefix og webmaster mail addresse er blevet gemt fra tidligere konfiguration. ';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'In <i>%s</i>, before <b>?></b>, insert:';
?>

==> piwigo-2.3.1.zip: piwigo/language/da_DK/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'Opgrader';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Denne side foreslår at opgradere databasen fra din gamle version af Piwigo til den nye version. Opgraderingsassistenten tror du burger en<strong>release %s</strong> (or equivalent).';
$lang['Upgrade from version %s to %s'] = 'Opgrader fra version %s til %s';
$lang['Statistics'] = 'Statistik';
$lang['total upgrade time'] = 'total opgraderings tid';
$lang['total SQL time'] = 'total SQL tid';
$lang['SQL queries'] = 'SQL queries';
$lang['Upgrade informations'] = 'Opgraderings information';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Udfør et vedligeholdelsescheck I [Administration>Tools>Maintenance] hvis du oplever problemer.';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'For en sikkerheds skyld er følgende plugins blevet deaktiveret. Check dine plugins opgraderinger før du reaktiverer dem:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Kun en administrator kan lave en opgradering: Login in herunder.';
$lang['You do not have access rights to run upgrade'] = 'Du har ikke adgangsrettighed til at køre en opgradering';
$lang['All sub-albums of private albums become private'] = 'Alle under-kategorier af private kategorier bliver private';
$lang['User permissions and group permissions have been erased'] = 'Bruger og gruppe tilladelser er blevet slettet';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Kun  thumbnails prefix og webmaster mail addresse er blevet gemt fra tidligere konfiguration. ';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'I <i>%s</i>, før <b>?></b>, indsæt:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Som en forholdsregel er følgende temaer blevet deaktiveret. Check for tema opgraderinger før du reaktiverer dem:';
?>
